@@ -11,7 +11,7 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 
-Version = '3.3'
+Version = '4.1'
 Build = '1'
 
 import sys
@@ -34,16 +34,11 @@ from clevenManageCapturedUI import *
 
 pathMain             = '/opt/cleven'                        # main path for the application
 pathStorage          = '/home/user/.cleven'                 # storage path for the application
-pathReaver           = '/home/user/.reaver'                 # storage path for reaver
 helperScript         = 'clevenHelper.sh'
 folderKeys           = 'keys'
 folderDictionaries   = 'dictionaries'
 folderCapturedData   = 'capturedData'
 
-reaverBinary         = 'reaver'
-reaverDatabase       = 'reaver.db'
-washBinary           = 'wash'
-
 skipSplash           = 'skipSplash'
 skipKernelCheck      = 'skipKernelCheck'
 skipVersionCheck     = 'skipVersionCheck'
@@ -141,11 +136,6 @@ class clevenCapture(QtGui.QMainWindow):
        QtCore.QObject.connect(self.ui.injectionButton,      QtCore.SIGNAL('clicked()'), self.executeInjection)
        QtCore.QObject.connect(self.ui.reaverButton,         QtCore.SIGNAL('clicked()'), self.executeReaver)
 
-       if reaverAvailability == False:
-          self.ui.reaverButton.setHidden(True)
-       if washAvailability == False:
-          self.ui.wpsRadio.setHidden(True)
-       
        self.ui.captureButton.setEnabled(False)
        self.ui.reaverButton.setEnabled(False)
        
@@ -205,7 +195,7 @@ class clevenCapture(QtGui.QMainWindow):
 
        if self.ui.wpsRadio.isChecked(): ##FIX splitting for new version of wash
           values = []
-          rValues = os.popen('sudo %s/%s wash' %(pathMain, helperScript)).read()
+          rValues = os.popen('sudo %s/%s wash %s' %(pathMain, helperScript, pathStorage)).read()
           rValues = rValues.split("\n")                     ##split them to create an entry for each in the list
           rValues = filter(None, rValues)                   ##remove unknown (empty)
           for i in rValues:                                 ##iterate on the values stored in the list
@@ -233,9 +223,8 @@ class clevenCapture(QtGui.QMainWindow):
        self.ui.captureButton.setEnabled(True)
        self.ui.captureButton.setHidden(False)
        if self.ui.wepRadio.isChecked() == False:
-          if reaverAvailability:
-             self.ui.reaverButton.setEnabled(True)
-             self.ui.reaverButton.setHidden(False)
+          self.ui.reaverButton.setEnabled(True)
+          self.ui.reaverButton.setHidden(False)
        
        if self.ui.scanList.currentRow() == -1:
           self.ui.textBrowser.clear()
@@ -820,6 +809,7 @@ class clevenAbout(QtGui.QMainWindow):
        <br><br><b>THANKS TO:</b> 
        <br><br><b>David Gnedt</b> (lxp) for the development of the bleeding-edge wlan drivers. You can support his work by sending him your donations. See for more info: http://david.gnedt.eu/blog/wl1251/ 
        <br><br><b>Ivaylo Dimitrov</b> (freemangordon) for the packaging of the bleeding-edge wlan drivers. 
+       <br><br><b>Pali Rohr</b> (pali) for the packaging of reaven and kernel-power. 
        <br><br><b>Benoit HERVIER</b> at http://khertan.net/ for the code used in this about window. 
        <br></center>''' % (Version, Build))
        
@@ -891,34 +881,6 @@ class clevenMain():
        os.system('mkdir -p %s/%s'      % (pathStorage,folderKeys))
     else:
        pass
-    
-    global reaverAvailability, washAvailability
-    reaverAvailability = False
-    washAvailability = False
-    
-    ##Check if reaver and/or wash is available in the home directory:
-    if os.path.exists(pathReaver):
-       if os.path.isfile(pathReaver + '/' + reaverBinary):
-          if os.WEXITSTATUS(os.system('sudo %s/%s copyReaver %s %s' % ( pathMain, helperScript, pathReaver, pathMain ))) == 0:
-             print 'INFO: found Reaver binary and made a copy'
-       if os.path.isfile(pathReaver + '/' + washBinary):
-          if os.WEXITSTATUS(os.system('sudo %s/%s copyWash %s %s' % ( pathMain, helperScript, pathReaver, pathMain ))) == 0:
-             print 'INFO: found Wash binary and made a copy'
-       if os.path.isfile(pathReaver + '/' + reaverDatabase):
-          if os.WEXITSTATUS(os.system('sudo %s/%s copyReaverDB %s %s' % ( pathMain, helperScript, pathReaver, pathMain ))) == 0:
-             print 'INFO: found Reaver database and made a copy'
-
-    ##Check if reaver is available to the application:
-    if os.path.isfile(pathMain + '/' + reaverBinary):
-       os.path.exists(pathReaver) or os.mkdir(pathReaver)
-       reaverAvailability = True
-       print 'INFO: Reaver is available for usage..'
-       
-    ##Check if wash is available to the application:
-    if os.path.isfile(pathMain + '/' + washBinary):
-       os.path.exists(pathReaver) or os.mkdir(pathReaver)
-       washAvailability = True
-       print 'INFO: Wash is available for usage..'
        
     app = QtGui.QApplication(sys.argv)
     myapp = clevenMainWindow()
